@@ -11,9 +11,9 @@ use warnings FATAL => 'all';
     $VERSION = eval $VERSION;
     # Note: This given version applies to all of this file's packages.
 
-    use namespace::autoclean 0.08;
+    use namespace::autoclean 0.09;
 
-    use Moose::Role 0.89;
+    use Moose::Role 0.90;
 
     requires 'export_for_new';
     requires 'which';
@@ -102,9 +102,9 @@ use warnings FATAL => 'all';
 
 { package Set::Relation::Mutable; # role
 
-    use namespace::autoclean 0.08;
+    use namespace::autoclean 0.09;
 
-    use Moose::Role 0.89;
+    use Moose::Role 0.90;
 
     with 'Set::Relation';
 
@@ -135,7 +135,7 @@ Relation data type for Perl
 
 =head1 VERSION
 
-This document describes Set::Relation version 0.12.2 for Perl 5.
+This document describes Set::Relation version 0.12.3 for Perl 5.
 
 =head1 SYNOPSIS
 
@@ -920,7 +920,7 @@ elements.  This method supports renaming attributes to each others' names.
 This method will fail if C<$map> specifies any old names that C<$topic>
 doesn't have, or any new names that are the same as C<$topic> attributes
 that aren't being renamed.  Note that this operation is also known as C<<
-{{<-}} >>.
+@{<-} >>.
 
 =head2 projection
 
@@ -932,7 +932,7 @@ which are named in its C<$attr_names> argument.  As a trivial case, this
 method's result is C<$topic> if C<$attr_names> lists all attributes of
 C<$topic>; or, it is a nullary relation if C<$attr_names> is empty.  This
 method will fail if C<$attr_names> specifies any attribute names that
-C<$topic> doesn't have.  Note that this operation is also known as C<{{}}>.
+C<$topic> doesn't have.  Note that this operation is also known as C<@{}>.
 
 =head2 cmpl_proj
 
@@ -940,7 +940,7 @@ C<method cmpl_proj of Set::Relation ($topic: Array|Str $attr_names)>
 
 This functional method is the same as C<projection> but that it results in
 the complementary subset of attributes of its invocant when given the same
-argument.  Note that this operation is also known as C<{{!}}>.
+argument.  Note that this operation is also known as C<@{!}>.
 
 =head2 wrap
 
@@ -961,7 +961,7 @@ same as C<TT>.  This method supports the new attribute having the same name
 as an old one being wrapped into it.  This method will fail if C<$inner>
 specifies any attribute names that C<$topic> doesn't have, or if C<$outer>
 is the same as a C<$topic> attribute that isn't being wrapped.  Note that
-this operation is also known as C<< {{@<-}} >>.
+this operation is also known as C<< @{%<-} >>.
 
 =head2 cmpl_wrap
 
@@ -970,7 +970,7 @@ Array|Str $cmpl_inner)>
 
 This functional method is the same as C<wrap> but that it wraps the
 complementary subset of attributes of C<$topic> to those specified by
-C<$cmpl_inner>.  Note that this operation is also known as C<< {{@<-!}} >>.
+C<$cmpl_inner>.  Note that this operation is also known as C<< @{%<-!} >>.
 
 =head2 unwrap
 
@@ -989,7 +989,7 @@ situation the names of the attributes to add to C<$topic> in place of
 C<$topic{$outer}> can not be determined from C<$topic{$outer}>.  This
 method will fail if C<$topic> has at least 1 tuple and C<$inner> does not
 match the names of the attributes of C<$topic{$outer}> for every tuple of
-C<$topic>.  Note that this operation is also known as C<< {{<-@}} >>.
+C<$topic>.  Note that this operation is also known as C<< @{<-%} >>.
 
 =head2 group
 
@@ -1019,7 +1019,7 @@ C<$topic> does).  This method supports the new attribute having the same
 name as an old one being grouped into it.  This method will fail if
 C<$inner> specifies any attribute names that C<$topic> doesn't have, or if
 C<$outer> is the same as C<$topic> attributes that aren't being grouped.
-Note that this operation is also known as I<nest> or C<< {{@@<-}} >>.
+Note that this operation is also known as I<nest> or C<< @{@<-} >>.
 
 =head2 cmpl_group
 
@@ -1028,7 +1028,7 @@ Array|Str $group_per)>
 
 This functional method is the same as C<group> but that it groups the
 complementary subset of attributes of C<$topic> to those specified by
-C<$group_per>.  Note that this operation is also known as C<< {{@@<-!}} >>.
+C<$group_per>.  Note that this operation is also known as C<< @{@<-!} >>.
 
 =head2 ungroup
 
@@ -1046,7 +1046,7 @@ have, or if C<$topic{$outer}> does not have a same-heading relation value
 for every tuple of C<$topic> (because then there would be no consistent set
 of attribute names to extend C<$topic> with), or if an attribute of
 C<$topic{$outer}> has the same name as another C<$topic> attribute.  Note
-that this operation is also known as I<unnest> or C<< {{<-@@}} >>.
+that this operation is also known as I<unnest> or C<< @{<-@} >>.
 
 =head2 tclose
 
@@ -1257,7 +1257,7 @@ is like C<cmpl_group> but that the single added attribute, rather than an
 RVA of the grouped C<$topic> attributes, has the cardinality that said RVA
 would have had.  The result's heading consists of the attributes named in
 C<$group_per> plus the attribute named in C<$count_attr_name> (a positive
-integer).  Note that this operation is also known as C<< {{#@@<-!}} >>.
+integer).  Note that this operation is also known as C<< @{#@<-!} >>.
 
 =head2 count_per_group
 
@@ -1845,8 +1845,8 @@ This file requires any version of Perl 5.x.y that is at least 5.8.1, and
 recommends one that is at least 5.10.1.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<namespace::autoclean-ver(0.08..*)|namespace::autoclean>,
-L<Moose::Role-ver(0.89..*)|Moose::Role>.
+L<namespace::autoclean-ver(0.09..*)|namespace::autoclean>,
+L<Moose::Role-ver(0.90..*)|Moose::Role>.
 
 =head1 INCOMPATIBILITIES
 
